<template>
    <div>
        <el-dialog
            title="选择项目名称"
            :visible.sync="dialogVisible"
            width="70%"
            top="5vh"
            :before-close="dialogBeforeClose"
        >
            <div>
                <div>
                    <el-form ref="searchForm" :model="searchForm" label-width="80px">
                        <el-row :gutter="10" style="display: flex">
                            <el-col :span="5.5">
                                <el-form-item label="年份">
                                    <el-date-picker
                                        v-model="searchForm['projectYear']"
                                        type="year"
                                        value-format="yyyy"
                                        @change="changeYear"
                                        placeholder="date"
                                    ></el-date-picker>
                                </el-form-item>
                            </el-col>
                            <el-col :span="5.5">
                                <el-form-item label="名称">
                                    <el-input
                                        placeholder="请输入名称"
                                        v-model="searchForm['projectName']"
                                    ></el-input>
                                </el-form-item>
                            </el-col>
                            <el-col :span="6">
                                <el-button size="small" @click="findinfo" type="primary"
                                    >查询</el-button
                                >
                                <el-button size="small" @click="handleReset" type="plain"
                                    >重置</el-button
                                >
                            </el-col>
                        </el-row>
                    </el-form>
                </div>
                <el-table
                    border
                    size="mini"
                    v-loading="loading"
                    ref="multipleSelection"
                    :data="tableData"
                    :style="{width: '100%'}"
                    height="400px"
                    row-key="getRowKeys"
                    highlight-selection-row
                    @select="selectChange"
                    @row-click="handleRowClick"
                    @select-all="selectAll"
                    :header-cell-style="{'text-align': 'center'}"
                    @selection-change="handleSelectionChange"
                >
                    <el-table-column type="selection" width="55"></el-table-column>

                    <el-table-column
                        prop="roadSegmentName"
                        label="路段"
                        align="center"
                        min-width="80"
                    ></el-table-column>
                    <el-table-column
                        prop="projectName"
                        label="项目名称"
                        align="left"
                        min-width="160"
                    >
                    </el-table-column>
                </el-table>
                <el-pagination
                    ref="paginationPanel"
                    align="right"
                    class="bbsl-pagination"
                    background
                    @size-change="handleSizeChange"
                    @current-change="handleCurrentChange"
                    :current-page="queryParam.pageBean.page"
                    :page-sizes="[20, 50, 200, , 500]"
                    :page-size="queryParam.pageBean.pageSize"
                    layout="total, sizes, prev, pager, next, jumper"
                    :total="queryParam.pageBean.total"
                ></el-pagination>
            </div>
            <div slot="footer">
                <el-button @click="dialogBeforeClose">取 消</el-button>
                <el-button type="primary" @click="save">确 定</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import basicData from '@/api/basicData.js'
export default {
    data() {
        return {
            dialogVisible: false,
            searchForm: {
                projectYear: '',
                ROAD_SEGMENT_ID_: '',
            },
            loading: false,
            tableData: [],
            multipleSelection: [],
            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                },
            },
            params: {},
            subscribeData: [],
            budgetIds: [],
            typeList: [],
        }
    },
    created() {
    },
    mounted() {
        let date = new Date()
        this.searchForm['projectYear'] = date.getFullYear().toString()
    },
    methods: {
        open(row, budgetIds) {
            console.log(row, 'row')
            this.dialogVisible = true
            this.params = row
            if(this.params.roadSegmentId){
                this.searchForm['ROAD_SEGMENT_ID_'] = this.params.roadSegmentId
            }
            this.getData()
            if (budgetIds) {
                this.budgetIds = budgetIds
            }
        },
        dialogBeforeClose() {
            this.dialogVisible = false
            this.searchForm['ROAD_SEGMENT_ID_'] = ''
        },
        findinfo() {
            this.getData()
        },
        handleReset() {
            let date = new Date()
            this.searchForm['projectYear'] = date.getFullYear().toString()
            this.searchForm['ROAD_SEGMENT_ID_'] = this.params.roadSegmentId
            this.searchForm['projectName'] = ''
            this.getData()
        },
        changeYear(val) {
            console.log(val, 'val')
            this.searchForm['projectYear'] = val
        },
        handleSelectionChange(val) {
            console.log(val, 'val')
            this.multipleSelection = val.map((item) => {
                return item
            })
        },
        getQuerysParams() {
            let {searchForm, queryParam} = this
            let {page, pageSize} = queryParam.pageBean
            let querys = []
            for (let i in searchForm) {
                    querys.push({
                        group: 'main',
                        operation: 'LIKE',
                        property: i,
                        relation: 'AND',
                        value: searchForm[i],
                    })
            }
            return {
                pageBean: {
                    page,
                    pageSize,
                    showTotal: true,
                },
                querys,
            }
        },
        getData() {
            this.loading = true
            this.queryParam = this.getQuerysParams()
            this.tableData = []
            this.$http
                .post('${yhxt}/bizEngineeringProject/v1/getJson', this.queryParam)
                .then((res) => {
                    console.log(res, 'resssss')
                    this.loading = false
                    this.queryParam.pageBean.total = res.data.total
                    this.queryParam.pageBean.page = res.data.page
                    this.queryParam.pageBean.pageSize = res.data.pageSize
                    this.tableData = res.data.rows
                    this.$nextTick(() => {
                        this.tableData.forEach((item, index) => {
                            if (this.params.projectId == item.id) {
                                this.$refs.multipleSelection.toggleRowSelection(
                                    this.$refs.multipleSelection.data[index],
                                    true
                                )
                            }
                        })
                    })
                })
        },
        selectChange(selection, row) {
            if (selection.length > 1) {
                const del_row = selection.shift()
                this.$refs.multipleSelection.toggleRowSelection(del_row, false)
            }
        },
        // // 点击行触发，选中或不选中复选框
        handleRowClick(row, column, event) {
            this.$refs.multipleSelection.toggleRowSelection(row)
            this.selectChange(this.multipleSelection)
        },
        selectAll(selection) {
            if (selection.length > 1) {
                selection.length = 1
            }
        },
        save() {
            this.dialogVisible = false
            this.$emit('common', this.multipleSelection)
        },
        handleSizeChange(val) {
            this.queryParam.pageBean.pageSize = val
            this.getData()
        },
        handleCurrentChange(val) {
            this.queryParam.pageBean.page = val
            this.getData()
        },
        getRowKeys(row) {
            return row.id
        },
    },
}
</script>

<style lang="scss" scoped></style>
